@@ -27,6 +27,7 @@ class BankTransaction(models.Model, BadiModel):
     card_hash = models.CharField(max_length=255, blank=True, null=True, verbose_name=_("Card Hash"))
     order_id = models.CharField(max_length=50, blank=True, null=True)
     amount = models.BigIntegerField(default=0, verbose_name=_("Amount"))
+    info = models.TextField(verbose_name=_("Info"), blank=True)
     data = models.TextField(verbose_name=_("Bank Response"), blank=True)
     created_at = models.DateTimeField(auto_now_add=True, blank=True)
 
@@ -54,6 +55,7 @@ class Transaction(models.Model, BadiModel):
     user = models.ForeignKey(User, related_name='transactions', on_delete=models.PROTECT, verbose_name=_("User"))
     amount = models.BigIntegerField(default=0, verbose_name=_("Amount"))
     type = models.CharField(max_length=2, choices=TYPES, verbose_name=_("Type"))
+    info = models.TextField(blank=True)
     date_time = models.DateTimeField(auto_now_add=True, blank=True, verbose_name=_("Time"))
     subject = models.CharField(max_length=255, verbose_name=_("Subject"), null=True, blank=True)
     bank_transaction = models.ForeignKey(BANK_TRANSACTION_MODEL, related_name='transactions', null=True, blank=True,
